GigeDevice

Struct GigeDevice 

pub struct GigeDevice { /* private fields */ }
GVCP device handle.

Implementations

Source

impl GigeDevice

pub async fn open(addr: SocketAddr) -> Result<Self, GigeError>

Connect to a device GVCP endpoint.

pub fn remote_addr(&self) -> SocketAddr

Return the remote GVCP socket address associated with this device.

pub async fn read_mem( &mut self, addr: u64, len: usize, ) -> Result<Vec<u8>, GigeError>

Read a block of memory from the remote device with chunking and retries.

pub async fn write_mem( &mut self, addr: u64, data: &[u8], ) -> Result<(), GigeError>

Write a block of memory to the remote device with chunking and retries.

pub async fn set_message_destination( &mut self, ip: Ipv4Addr, port: u16, ) -> Result<(), GigeError>

Configure the message channel destination address/port.

pub async fn set_stream_destination( &mut self, channel: u32, ip: Ipv4Addr, port: u16, ) -> Result<(), GigeError>

Configure the GVSP host destination for the provided channel.

pub async fn set_stream_packet_size( &mut self, channel: u32, packet_size: u32, ) -> Result<(), GigeError>

Configure the packet size for the stream channel.

pub async fn set_stream_packet_delay( &mut self, channel: u32, packet_delay: u32, ) -> Result<(), GigeError>

Configure the packet delay (GevSCPD).

pub async fn negotiate_stream( &mut self, channel: u32, iface: &Iface, port: u16, target_mtu: Option<u32>, ) -> Result<StreamParams, GigeError>

Negotiate GVSP parameters with the device given the host interface.

pub async fn enable_event_raw( &mut self, id: u16, on: bool, ) -> Result<(), GigeError>

Enable or disable delivery of the provided event identifier.

pub async fn request_resend( &mut self, block_id: u16, first_packet: u16, last_packet: u16, ) -> Result<(), GigeError>

Request resend of a packet range for the provided block identifier.