FrameAssembly

Struct FrameAssembly 

pub struct FrameAssembly { /* private fields */ }
Representation of a partially received frame.

Implementations

Source

impl FrameAssembly

pub fn new( block_id: u16, expected_packets: usize, packet_payload: usize, buffer: BytesMut, deadline: Instant, ) -> Self

Create a new frame assembly using the supplied buffer.

pub fn block_id(&self) -> u16

Returns the block identifier associated with this frame.

pub fn is_expired(&self, now: Instant) -> bool

Whether the reassembly deadline has elapsed.

pub fn ingest(&mut self, packet_id: usize, payload: &[u8]) -> bool

Insert a packet payload into the buffer.

pub fn finish(self) -> Option<Bytes>

Finalise the frame if all packets have been received.