pub struct ResendPlanner { /* private fields */ }Expand description
Helper struct tracking resend attempts for a given block.
Implementations
Sourceimpl ResendPlanner
impl ResendPlanner
pub fn new(max_retries: u32, base_delay: Duration) -> Self
Sourcepub fn should_resend(&self, now: Instant) -> bool
pub fn should_resend(&self, now: Instant) -> bool
Determine whether a resend can be attempted at the provided instant.
Sourcepub fn record_attempt(&mut self, now: Instant, jitter: Duration)
pub fn record_attempt(&mut self, now: Instant, jitter: Duration)
Record a resend attempt and compute the next deadline.
Sourcepub fn is_exhausted(&self) -> bool
pub fn is_exhausted(&self) -> bool
Whether the resend planner exhausted all retries.