pub struct Iface { /* private fields */ }Expand description
Representation of a host network interface.
Implementations
Sourceimpl Iface
impl Iface
Sourcepub fn from_system(name: &str) -> Result<Self>
pub fn from_system(name: &str) -> Result<Self>
Resolve an interface from the operating system by its name.
Sourcepub fn from_ipv4(addr: Ipv4Addr) -> Result<Self>
pub fn from_ipv4(addr: Ipv4Addr) -> Result<Self>
Resolve an interface by its primary IPv4 address.
Sourcepub fn index(&self) -> u32
pub fn index(&self) -> u32
Interface index as reported by the kernel. The index is used by some socket options (e.g. multicast subscriptions).