pub struct TimeSync { /* private fields */ }Expand description
Maintain a linear mapping between device ticks and host time.
Implementations
Sourceimpl TimeSync
impl TimeSync
Sourcepub fn coefficients(&self) -> (f64, f64)
pub fn coefficients(&self) -> (f64, f64)
Return the current slope and intercept of the time mapping.
Sourcepub fn update(&mut self, dev_ts: u64, host_instant: Instant)
pub fn update(&mut self, dev_ts: u64, host_instant: Instant)
Add a new measurement pair to the regression window.
Sourcepub fn to_host_time(&self, dev_ts: u64) -> SystemTime
pub fn to_host_time(&self, dev_ts: u64) -> SystemTime
Convert a device timestamp into a host SystemTime.