pub struct StreamConfig {
pub dest: StreamDest,
pub iface: Iface,
pub packet_size: Option<u32>,
pub packet_delay: Option<u32>,
pub source_filter: Option<Ipv4Addr>,
pub resend_enabled: bool,
}Expand description
Stream configuration shared between the control plane and GVSP receiver.
Fields
dest: StreamDestDestination configuration for the GVSP stream.
iface: IfaceInterface used for receiving packets and multicast subscription.
packet_size: Option<u32>Override for GVSP packet size determined via control plane.
packet_delay: Option<u32>Override for GVSP packet delay determined via control plane.
source_filter: Option<Ipv4Addr>Optional source filter restricting packets to the configured IPv4 address.
resend_enabled: boolWhether GVCP resend requests should be issued when drops are detected.